@@ -14,6 +14,12 @@ import aws_cdk.aws_logs
 import aws_cdk.aws_s3
 import aws_cdk.core
 import aws_solutions_konstruk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-konstruk/aws-kinesisfirehose-s3", "0.8.1", __name__[0:-6], "aws-kinesisfirehose-s3@0.8.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
